pub struct SyncConcurrentPyrightClient { /* private fields */ }Expand description
Sync concurrent Pyright LSP client - uses message passing for true parallelism Multiple threads can make requests simultaneously without blocking each other!
Implementations
Sourceimpl SyncConcurrentPyrightClient
impl SyncConcurrentPyrightClient
Sourcepub fn new(workspace_root: Option<&str>) -> Result<Self>
pub fn new(workspace_root: Option<&str>) -> Result<Self>
Create and initialize a new sync concurrent pyright client