Module dependency_collector

Module dependency_collector 

Structs

DependencyCollectionResult
Collection result for dependency analysis

Functions

clear_module_cache
Clear the module analysis cache
collect_deprecated_from_dependencies
Collect all deprecated functions from imported modules
collect_deprecated_from_dependencies_with_paths
Collect all deprecated functions from imported modules with additional search paths
collect_deprecated_from_module
Collect all deprecated functions from a single module
collect_deprecated_from_module_with_paths
Collect all deprecated functions from a single module with additional search paths
collect_imports_from_source
Extract all imports from a Python source file
might_contain_replace_me
Quick check if source might contain replace_me
resolve_module_path
Resolve a module name to its actual import path
scan_file_with_dependencies
Scan a file and collect deprecated functions from it and its dependencies