pub fn collect_deprecated_from_module_with_paths(
module_path: &str,
additional_paths: &[String],
) -> Result<DependencyCollectionResult>Expand description
Collect all deprecated functions from a single module with additional search paths
pub fn collect_deprecated_from_module_with_paths(
module_path: &str,
additional_paths: &[String],
) -> Result<DependencyCollectionResult>Collect all deprecated functions from a single module with additional search paths