pub struct MypyTypeIntrospector { /* private fields */ }Expand description
Mypy-based type introspection using dmypy daemon
Implementations
Sourceimpl MypyTypeIntrospector
impl MypyTypeIntrospector
pub fn new(workspace_root: Option<&str>) -> Result<Self, String>
Sourcepub fn ensure_daemon_started(&mut self) -> Result<(), String>
pub fn ensure_daemon_started(&mut self) -> Result<(), String>
Start the mypy daemon if not already running
Sourcepub fn get_type_at_position(
&mut self,
file_path: &str,
line: usize,
column: usize,
) -> Result<Option<String>, String>
pub fn get_type_at_position( &mut self, file_path: &str, line: usize, column: usize, ) -> Result<Option<String>, String>
Get the type of an expression at a specific location
Sourcepub fn resolve_type_fqn(
&mut self,
_file_path: &str,
type_name: &str,
) -> Result<Option<String>, String>
pub fn resolve_type_fqn( &mut self, _file_path: &str, type_name: &str, ) -> Result<Option<String>, String>
Get the fully qualified name of a type
Sourcepub fn invalidate_file(&mut self, file_path: &str) -> Result<(), String>
pub fn invalidate_file(&mut self, file_path: &str) -> Result<(), String>
Invalidate cached type information for a file after modifications
Sourcepub fn stop_daemon(&mut self) -> Result<(), String>
pub fn stop_daemon(&mut self) -> Result<(), String>
Stop the dmypy daemon