StringOptimizations

Trait StringOptimizations 

pub trait StringOptimizations {
    // Required methods
    fn as_cow(&self) -> CowStr<'_>;
    fn to_shared(&self) -> SharedString;
}
Convert common string operations to use Cow to avoid clones

Required Methods

fn as_cow(&self) -> CowStr<'_>

Get a borrowed or owned string depending on whether modification is needed

fn to_shared(&self) -> SharedString

Share a string across multiple owners without cloning

Implementations on Foreign Types

Source

impl StringOptimizations for &str

Source

impl StringOptimizations for String

Implementors