Module pyright_lsp

Module pyright_lsp 

Pyright LSP integration for type inference

This module provides type querying capabilities using pyright language server.

Structs

PyrightLspClient
Pyright LSP client

Traits

PyrightLspClientTrait
Trait for pyright-like LSP clients that can be used in TypeIntrospectionContext

Functions

get_type_with_pyright
Get type for a variable at a specific location using pyright