Module scanner

Module scanner 

Fast scanner for @replace_me decorators.

This module provides a fast pre-filter to skip files that definitely don’t contain @replace_me decorators, avoiding expensive LibCST parsing.

Structs

FindFilesIterator
Iterator implementation for finding files with @replace_me

Functions

find_files_with_replace_me
Iterator that yields files that might contain @replace_me decorators.
find_python_files_with_replace_me
Recursively find all Python files in a directory that might contain @replace_me
might_contain_replace_me
Quick check if content might contain @replace_me decorators.
scan_file
Read a file and return content if it might contain @replace_me.