might_contain_replace_me

Function might_contain_replace_me 

pub fn might_contain_replace_me(content: &str) -> bool
Quick check if content might contain @replace_me decorators.

This is a fast pre-filter that uses regex to avoid parsing files that definitely don’t contain @replace_me. It errs on the side of false positives to avoid missing any actual decorators.