pub struct TypeIntrospectionContext { /* private fields */ }Expand description
Context that holds type introspection clients across multiple file migrations
Implementations
Sourceimpl TypeIntrospectionContext
impl TypeIntrospectionContext
Sourcepub fn new(method: TypeIntrospectionMethod) -> Result<Self>
pub fn new(method: TypeIntrospectionMethod) -> Result<Self>
Create a new type introspection context
Sourcepub fn new_with_workspace(
method: TypeIntrospectionMethod,
workspace_root: Option<&str>,
) -> Result<Self>
pub fn new_with_workspace( method: TypeIntrospectionMethod, workspace_root: Option<&str>, ) -> Result<Self>
Create a new type introspection context with a specific workspace root
Sourcepub fn method(&self) -> TypeIntrospectionMethod
pub fn method(&self) -> TypeIntrospectionMethod
Get the type introspection method
Sourcepub fn pyright_client(
&self,
) -> Option<Rc<RefCell<Box<dyn PyrightLspClientTrait>>>>
pub fn pyright_client( &self, ) -> Option<Rc<RefCell<Box<dyn PyrightLspClientTrait>>>>
Get a clone of the pyright client if available
Sourcepub fn mypy_client(&self) -> Option<Rc<RefCell<MypyTypeIntrospector>>>
pub fn mypy_client(&self) -> Option<Rc<RefCell<MypyTypeIntrospector>>>
Get a clone of the mypy client if available
Sourcepub fn open_file(&mut self, file_path: &Path, content: &str) -> Result<()>
pub fn open_file(&mut self, file_path: &Path, content: &str) -> Result<()>
Open a file for type introspection
Sourcepub fn update_file(&mut self, file_path: &Path, content: &str) -> Result<()>
pub fn update_file(&mut self, file_path: &Path, content: &str) -> Result<()>
Update a file after modifications
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Check if the context has been shutdown