pub struct UnifiedVisitor { /* private fields */ }Expand description
Unified visitor that handles collection and cleanup operations
Implementations
Sourceimpl UnifiedVisitor
impl UnifiedVisitor
Sourcepub fn new_for_collection(module_name: &str, file_path: Option<&Path>) -> Self
pub fn new_for_collection(module_name: &str, file_path: Option<&Path>) -> Self
Create a new unified visitor for collection
Sourcepub fn new_for_removal_with_callback(
module_name: &str,
file_path: Option<&Path>,
should_remove: ShouldRemoveCallback,
) -> Self
pub fn new_for_removal_with_callback( module_name: &str, file_path: Option<&Path>, should_remove: ShouldRemoveCallback, ) -> Self
Create a new unified visitor for removal with a callback
Sourcepub fn new_for_removal(
module_name: &str,
file_path: Option<&Path>,
before_version: Option<&str>,
remove_all: bool,
current_version: Option<&str>,
) -> Self
pub fn new_for_removal( module_name: &str, file_path: Option<&Path>, before_version: Option<&str>, remove_all: bool, current_version: Option<&str>, ) -> Self
Create a new unified visitor for removal with version criteria
Sourcepub fn process_source(self, source: String) -> Result<UnifiedResult>
pub fn process_source(self, source: String) -> Result<UnifiedResult>
Process source code according to the operation mode
Sourcepub fn get_builtins(&self) -> &HashSet<String>
pub fn get_builtins(&self) -> &HashSet<String>
Get the builtins set