Structs
- Dependency
Collection Result - Collection result for dependency analysis
Functions
- clear_
module_ cache - Clear the module analysis cache
- collect_
deprecated_ from_ dependencies - Collect all deprecated functions from imported modules
- collect_
deprecated_ from_ dependencies_ with_ paths - Collect all deprecated functions from imported modules with additional search paths
- collect_
deprecated_ from_ module - Collect all deprecated functions from a single module
- collect_
deprecated_ from_ module_ with_ paths - Collect all deprecated functions from a single module with additional search paths
- collect_
imports_ from_ source - Extract all imports from a Python source file
- might_
contain_ replace_ me - Quick check if source might contain replace_me
- resolve_
module_ path - Resolve a module name to its actual import path
- scan_
file_ with_ dependencies - Scan a file and collect deprecated functions from it and its dependencies