Pyright LSP integration for type inference
This module provides type querying capabilities using pyright language server.
Structs
- Pyright
LspClient - Pyright LSP client
Traits
- Pyright
LspClient Trait - Trait for pyright-like LSP clients that can be used in TypeIntrospectionContext
Functions
- get_
type_ with_ pyright - Get type for a variable at a specific location using pyright