pub fn remove_decorators(
source: &str,
before_version: Option<&str>,
remove_all: bool,
current_version: Option<&str>,
) -> Result<(usize, String)>Expand description
Remove @replace_me decorated functions from source code
This removes entire functions decorated with @replace_me, not just the decorators. This should only be used after migration is complete and library authors want to clean up their codebase.
Returns a tuple of (removed_count, resulting_source)