Python parser and CST manipulation using Ruff’s parser.
This module provides a Rust implementation that preserves formatting and integrates with mypy for type inference.
Structs
- Function
Call Replacer - Visitor to find and replace function calls
- Python
Module - Parse Python source code preserving all formatting information
Functions
- apply_
replacements - Apply replacements to source code preserving formatting
- collect_
deprecated_ functions - Collect deprecated functions using Ruff’s AST For now, we delegate to LibCST collector until we implement full extraction
- migrate_
file_ with_ improved_ ruff - Compatibility function for import tracking tests This provides the same interface as the old ruff_parser_improved module
- migrate_
file_ with_ ruff - Main entry point for migrating a file using Ruff parser