Fast scanner for @replace_me decorators.
This module provides a fast pre-filter to skip files that definitely don’t contain @replace_me decorators, avoiding expensive LibCST parsing.
Structs
- Find
Files Iterator - Iterator implementation for finding files with @replace_me
Functions
- find_
files_ with_ replace_ me - Iterator that yields files that might contain @replace_me decorators.
- find_
python_ files_ with_ replace_ me - Recursively find all Python files in a directory that might contain @replace_me
- might_
contain_ replace_ me - Quick check if content might contain @replace_me decorators.
- scan_
file - Read a file and return content if it might contain @replace_me.