Function scan_file
Source pub fn scan_file(file_path: &str) -> Result<Option<String>>
Read a file and return content if it might contain @replace_me.
Arguments
file_path - Path to Python file
Returns
Ok(Some(content)) - File content if it might contain @replace_me
Ok(None) - File doesn’t contain @replace_me
Err(_) - File cannot be read or is not valid UTF-8